@@ -4,8 +4,8 @@ from zope.interface            import Interface, implements
 from zope.schema               import TextLine
 from zope.schema.fieldproperty import FieldProperty
 
-ALPHA = re.compile('^[a-zA-Z0-9_\-\.,\s]+$')
-ADDR  = re.compile('^[a-zA-Z0-9_\-\#\.\/,\s]+$')
+ALPHA = re.compile(r'^[\w\-\.,\s]+$', re.IGNORECASE | re.UNICODE)
+ADDR  = re.compile(r'^[\w\-\#\.\/,\s]+$', re.IGNORECASE | re.UNICODE)
 
 class IAddress(Interface):
     """Defines an interface for address types."""
@@ -18,8 +18,8 @@ class IAddress(Interface):
     state       = TextLine(title=u'State',        description=u'State of residence',   required=False, constraint=ALPHA.match, max_length=800)
     country     = TextLine(title=u'Country',      description=u'Country of residence', required=False, constraint=ALPHA.match, max_length=1000)
     postal_code = TextLine(title=u'Postal Code',  description=u'Postal code',          required=False, constraint=ALPHA.match, max_length=100)
-    phone       = TextLine(title=u'Phone Number', description=u'Phone number',         required=False, constraint=re.compile('^[0-9()-.,\s]+$').match, max_length=25)
-    fax         = TextLine(title=u'Fax Number',   description=u'Fax number',           required=False, constraint=re.compile('^[0-9()-.,\s]+$').match, max_length=25)
+    phone       = TextLine(title=u'Phone Number', description=u'Phone number',         required=False, constraint=re.compile(r'^[0-9()-.,\s]+$').match, max_length=25)
+    fax         = TextLine(title=u'Fax Number',   description=u'Fax number',           required=False, constraint=re.compile(r'^[0-9()-.,\s]+$').match, max_length=25)
 
 class SAddress(object):
     """Reifier of an address schema object."""
