@@ -8,8 +8,8 @@ from zope.interface            import Interface, implements
 from zope.schema               import Object, TextLine, Int, Choice, Datetime
 from zope.schema.fieldproperty import FieldProperty
 
-ALPHA      = re.compile('^[a-zA-Z0-9_\-.,\s]+$')
-CURRENCY   = re.compile('^[0-9]+.[0-9][0-9]$')
+ALPHA      = re.compile(r'^[\w\-.,\s]+$', re.IGNORECASE | re.UNICODE)
+CURRENCY   = re.compile(r'^[0-9]+.[0-9][0-9]$')
 
 # Super parent interfaces
 class IAuthnetSubscription(transaction.ITransaction):
